# (C) Datadog, Inc. 2018
# All rights reserved
# Licensed under a 3-clause BSD style license (see LICENSE)
import json
import os
import sys

from .validate import validate_py3


def main():
    """Run validate on a single python file"""
    if len(sys.argv) != 2:
        sys.stderr.write("No python file specified.\n")
        sys.stderr.flush()
        sys.exit(1)

    file_path = os.path.realpath(sys.argv[1].decode(sys.getfilesystemencoding()))
    if not os.path.exists(file_path):
        sys.stderr.write(u"{} does not exist.\n".format(file_path))
        sys.stderr.flush()
        sys.exit(1)

    results = validate_py3(file_path)
    if results:
        print(json.dumps(results))
    else:
        print('[]')



# (C) Datadog, Inc. 2018
# All rights reserved
# Licensed under a 3-clause BSD style license (see LICENSE)

from io import open
from os import path

from setuptools import setup


HERE = path.dirname(path.abspath(__file__))

with open(path.join(HERE, 'README.md'), 'r', encoding='utf-8') as f:
    README = f.read()


setup(
    name='datadog-a7',
    version="0.0.5",

    description='The Datadog Checks Shared Tools',
    long_description=README,
    long_description_content_type='text/markdown',
    keywords='datadog agent checks shared tools',

    url='https://github.com/DataDog/datadog-checks-shared',
    author='Datadog',
    author_email='packages@datadoghq.com',
    license='BSD',

    # See https://pypi.org/classifiers
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],

    packages=['a7'],
    install_requires=['pylint'],
    include_package_data=True,

    entry_points={
        'console_scripts': [
            'a7_validate = a7:main',
        ],
    },
)



# (C) Datadog, Inc. 2018
# All rights reserved
# Licensed under a 3-clause BSD style license (see LICENSE)

import json
from contextlib import closing
try:
    from StringIO import StringIO
except ImportError:
    from io import StringIO

from pylint.lint import PyLinter, fix_import_path
from pylint.reporters.json import JSONReporter


def validate_py3(path_to_module):
    """
    Run pylint python3 validation on the python module/package provided
    """
    with closing(StringIO()) as out:
        linter = PyLinter(reporter=JSONReporter(output=out))
        linter.load_default_plugins()
        linter.python3_porting_mode()
        # Disable `no-absolute-import`, which checks for a behaviour that's already part of python 2.7
        # cf https://www.python.org/dev/peps/pep-0328/
        linter.disable("no-absolute-import")
        with fix_import_path([path_to_module]):
            linter.check(path_to_module)
            linter.generate_reports()
        raw_results = json.loads(out.getvalue() or "{}")

    results = []
    for problem in raw_results:
        # An issue found by pylint is a dict like
        # {
        #     "message": "Calling a dict.iter*() method",
        #     "obj": "OpenFilesCheck.check",
        #     "column": 27,
        #     "path": "/path/to/file.py",
        #     "line": 235,
        #     "message-id": "W1620",
        #     "type": "warning",
        #     "symbol": "dict-iter-method",co
        #     "module": "file"
        # }
        results.append(
            {
                "message": "Line {}, column {}: {}".format(problem["line"], problem["column"], problem["message"]),
                "path": problem["path"],
            }
        )

    return results
